@@ -26,21 +26,25 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-# $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
+# $ORCA_VERSION
 #
-version     = "2.91.6"
+version     = "41.0"
+
+# The revision if built from git; otherwise an empty string
+#
+revision = "41b7a370a"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/orca/bld"
+prefix      = "/home/jd/checkout/orca/bld"
 
 # The package name (should be "orca").
 #
 package     = "orca"
 
-# The name of the data directory (usually "share").
+# The location of the data directory (usually "share").
 #
-datadirname = "share"
+datadir = "${prefix}/share".replace('${prefix}', '/home/jd/checkout/orca/bld')
 
 # The directory where we could find liblouis translation tables.
 #
